// This file contains definitions of game logic for the Prison Cell
#include "game\all_definitions.h"

/* room events */
void action_cell_on_room_draw(void)
{
	picture_draw(PICTURE_CELL,40,0);
	// no other checks, because we never go back to this room
}


void action_cell_on_room_enter(void)
{	
	console_print("Welcome to Adventure Studio!\n\nThis framework allows to create\nadventure games easily!",true);
	console_print("You can develop and debug the game in a modern IDE and then...\n...just compile it for Atari!",true);
}

/* actions on objects */

void action_cell_examine(void)
{
	if (area_activity_check(OBJECT_CELL_FIRE))
	{
		console_print("The fire is spreading in the cell.",true);
	}
	else
	{
		console_print("A stench of filth emanates from the pile of straw which has provided you with bedding. Many times you have seen the heavy oak door swing open to herald another monotonous visit from your Skorl captor.",true);
	}
}

void action_cell_window_examine(void)
{
	console_print("The tiny window is set high in the damp stone wall.",true);
}

void action_cell_window_look_through(void)
{
	console_print("The window is out of reach.",true);
}

void action_cell_torch_examine(void)
{
	console_print("The foul-smelling torch supplies little illumination, but abundant, acrid smoke.",true);
}

void action_cell_torch_get(void)
{
	console_print("Your fumbling hand reaches out. The torch slips and falls onto your precious bed.",true);
	area_activity_off(OBJECT_CELL_TORCH);
	area_activity_on(OBJECT_CELL_FIRE);
	// Show picture change
	picture_draw(PICTURE_CELL_FIRE,84,35);
}

void action_cell_fire_get(void)
{
	console_print("You reach into the fire and quickly pull back your hand as it starts to roast.",true);
}


void action_cell_door_open(void)
{
	if (object_flags_check(OBJECT_CELL_DOOR,OBJECT_CELL_DOOR_LOCKED))
	{
		console_print("The door is locked.",true);
	}
	else
	{
		if (!object_flags_check(OBJECT_CELL_DOOR,OBJECT_CELL_DOOR_CLOSED))
		{
			console_print("The door is already open.",true);
		}
		else
		{
			object_flags_zero(OBJECT_CELL_DOOR,OBJECT_CELL_DOOR_CLOSED);
			console_print("You opened the door.",true);
			if (room_current_get()==ROOM_CELL)
				picture_draw(PICTURE_CELL_DOOR_OPEN,44,45);
			else
				picture_draw(PICTURE_HALL_DOOR_OPEN,52,59);
		}
	}
}

void action_cell_door_close(void)
{
	if (object_flags_check(OBJECT_CELL_DOOR,OBJECT_CELL_DOOR_CLOSED))
	{
		console_print("The door is already closed.",true);
	}
	else
	{
		object_flags_set(OBJECT_CELL_DOOR,OBJECT_CELL_DOOR_CLOSED);
		console_print("You closed the door.",true);
		if (room_current_get()==ROOM_HALL)
		{
			picture_draw(PICTURE_HALL,20,0);
		}
	}
}

void action_cell_door_kick(void)
{
	picture_draw(PICTURE_CELL_DOOR_OPEN,44,45);
	picture_draw(PICTURE_CELL_GUARD,48,55);
	console_print("The Skorl guard opens the door and enters.\n",true);
	if (area_activity_check(OBJECT_CELL_FIRE))
	{
		picture_draw(PICTURE_CELL_DOOR_OPEN,44,45);
		picture_draw(PICTURE_CELL_GUARD,75,55);
		object_flags_zero(OBJECT_CELL_DOOR,OBJECT_CELL_DOOR_CLOSED|OBJECT_CELL_DOOR_LOCKED);
		object_action_replace(OBJECT_CELL_DOOR,action_cell_door_kick,action_cell_door_enter,"Enter");
		console_print("\"Oh no! That stupid 'uman on fire! If 'e's to well done da lads will 'ave me skinned!\"",true);
	}
	else
	{
		console_print("\"Be quiet, stupid 'uman!\"",true);
		action_guard_attacks_player();
	}
}

void action_cell_door_unlock(void)
{
	if (!object_flags_check(OBJECT_CELL_DOOR,OBJECT_CELL_DOOR_LOCKED))
	{
		console_print("The door is unlocked.",true);
		return;
	}
	if (room_current_get()==ROOM_CELL)
	{
		console_print("It must be bolted from the other side.",true);
		return;
	}
	else // we are in Hall
	{
		if (!object_flags_check(OBJECT_CELL_DOOR,OBJECT_CELL_DOOR_CLOSED))
		{
			console_print("The door is open.",true);
			return;
		}
		object_flags_zero(OBJECT_CELL_DOOR,OBJECT_CELL_DOOR_LOCKED);
		console_print("With a clank, the bolt slides open.",true);
	}
}

void action_cell_door_lock(void)
{
	if (object_flags_check(OBJECT_CELL_DOOR,OBJECT_CELL_DOOR_LOCKED))
	{
		console_print("The door is already locked.",true);
		return;
	}
	if (!object_flags_check(OBJECT_CELL_DOOR,OBJECT_CELL_DOOR_CLOSED))
	{
		console_print("The door is open.",true);
	}
	else
	{
		if (room_current_get()==ROOM_HALL)
		{
			console_print("You swing the heavy bolt into place, trapping the witless and unwary Skorl guard in the cell.",true);
			object_flags_set(OBJECT_CELL_DOOR,OBJECT_CELL_DOOR_LOCKED);
		}
	}
}

void action_cell_door_enter(void)
{
	if (object_flags_check(OBJECT_CELL_DOOR,OBJECT_CELL_DOOR_CLOSED))
	{
		console_print("The door is closed.",true);
	}
	else
	{
		object_action_replace(OBJECT_CELL_DOOR,action_cell_door_enter,action_cell_door_lock,"Lock");
		room_current_set(ROOM_HALL);	
	}
}
