// This file contains definitions of game logic for the Prison Hall
#include "game\all_definitions.h"

/* room events */

void action_hall_on_room_draw(void)
{
	picture_draw(room_current_picture_get(),20,0);
	if (!object_flags_check(OBJECT_CELL_DOOR,OBJECT_CELL_DOOR_CLOSED))
	{
		picture_draw(PICTURE_HALL_DOOR_OPEN,52,59);
	}
}

void action_hall_on_room_exit(void)
{
	// if player leaves the room and doors are not locked, then he is caught by the guard.
	if (!object_flags_check(OBJECT_CELL_DOOR,OBJECT_CELL_DOOR_LOCKED))
	{
		picture_draw(PICTURE_HALL_DOOR_OPEN,52,59);
		console_print("Ooops...\nDid you forgot to lock the door?",true);
		action_guard_attacks_player();
	}
	else if (object_value_get(OBJECT_HALL_PRISONER)==OBJECT_PRISONER_YELLING)
		action_hall_prisoner_talk_to();
}

/* actions on objects */

void action_hall_examine(void)
{
	console_print("A wretched prisoner hangs pitifully from manacles fixed firmly to the wall.",true);
}

void action_hall_sniff(void)
{
	console_print("The room reeks with the smell of neglects which has permeated the decaying stones.",true);
}

void action_hall_prisoner_examine(void)
{
	console_print("The prisoner wears a shirt with C= sign on it.",true);
}

void action_hall_prisoner_kill(void)
{
	console_print("You are an Atari beliver, but not an orthodox.",true);
}

void action_hall_prisoner_talk_to(void)
{
	console_print("Prisoner says:\n\"",false);
	switch (random()%4)
	{
	case 0:
		console_print("Atari sucks!\"\n",true);
		break;
	case 1:
		console_print("We have NUFLI graphics!\"\n",true);
		break;
	case 2:
		console_print("Commodore has better sprites!\"\n",true);
		break;
	case 3:
		console_print("C64! Commodore! C64!\"\n",true);
		break;
	}
	// If he was quiet, he starts to yell when player leaves the room
	if (object_value_get(OBJECT_HALL_PRISONER)==OBJECT_PRISONER_QUIET)
	{
		object_value_set(OBJECT_HALL_PRISONER,OBJECT_PRISONER_YELLING);
		console_print("Damn! It must be a fanatic Commodore\nuser. You have to make him shut up!\n",true);
		object_action_replace(OBJECT_HALL_PRISONER,ACTION_NONE,action_hall_prisoner_kill,"Kill");
		object_action_replace(OBJECT_HALL_PRISONER,ACTION_NONE,action_hall_prisoner_give_item,"Give");
	}
}

void action_hall_prisoner_give_item(void)
{
	object_id obj;
	if (container_get_number_of_items(CONTAINER_INVENTORY)==0)
	{
		console_print("You have nothing to give.",true);
		return;
	}
	obj=ui_container_choose_item(CONTAINER_INVENTORY);
	switch (obj)
	{
	case OBJECT_CREATED_IMPROVED_BEER:
		action_hall_prisoner_falls_asleep();
		break;
	case OBJECT_CORRIDOR_BEER_BOTTLE:
		console_print("Are you crazy? You have just one bottle of beer!\n",true);
		break;
	case OBJECT_CORRIDOR_HERBS:
		console_print("The prisoner won't eat that and you are too calm to force him.\n",true);
		break;
	case OBJECT_NONE: // if nothing selected
		break;
	default:
		console_print("You can't give this item.",true);
	}
}

void action_hall_right_exit_enter(void)
{
	room_current_set(ROOM_CORRIDOR);	
}

// Other actions

void action_guard_attacks_player(void)
{
	// show picture and restart game
	picture_draw(PICTURE_DEATH,24,0);
	// The game ends here
	for(;;)
	{
		console_print("The game ends here.\nWait for the load/save/restart feature! :)",true);
	}
}

void action_hall_prisoner_falls_asleep(void)
{
	console_print("\"Beer! For me? Thanks!\"\n",false);
	console_print("The prisoner slowly drinks improved beer from the bottle.\n",false);
	console_print("After a moment he falls asleep.",true);
	object_value_set(OBJECT_HALL_PRISONER,OBJECT_PRISONER_SLEEPING);
	area_activity_off(OBJECT_HALL_PRISONER);
	container_remove(CONTAINER_INVENTORY,container_find(CONTAINER_INVENTORY,OBJECT_CREATED_IMPROVED_BEER));
}